#
# spec file for package xcb-proto
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define dirsuffix 1.16.0
%if 0%{?suse_version} >= 1500
%bcond_with python2
%else
%bcond_without python2
%endif
Name:           xcb-proto
Version:        7.6_%{dirsuffix}
Release:        1.1
Summary:        The X11 Protocol: X Protocol C Bindings
License:        X11
Group:          Development/Libraries/X11
URL:            http://xorg.freedesktop.org/
#Git-Web:	https://cgit.freedesktop.org/xcb/proto
Source:         http://xorg.freedesktop.org/archive/individual/proto/%{name}-%{dirsuffix}.tar.xz
BuildRequires:  autoconf >= 2.57
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
%if %{with python2}
BuildRequires:  python2-base
%else
BuildRequires:  python3-base
%endif

%description
The XCB protocol headers for X11 development. xcb-proto provides the
XML-XCB protocol descriptions that libxcb uses to generate the majority of
its code and API.

%package devel
Summary:        The X11 Protocol: X Protocol C Bindings
Group:          Development/Libraries/X11
#Provides:       xorg-x11-proto-devel = 7.6
#Obsoletes:      xorg-x11-proto-devel <= 7.6
%if %{with python2}
Requires:       python2-xcb-proto-devel = %{version}
%else
Requires:       python3-xcb-proto-devel = %{version}
%endif

%description devel
The XCB protocol headers for X11 development. xcb-proto provides the
XML-XCB protocol descriptions that libxcb uses to generate the majority of
its code and API.

%package -n python2-xcb-proto-devel
Summary:        Python libraries mandatory for XML-XCB Development
Group:          Development/Libraries/X11
Provides:       python-xcb-proto-devel = %{version}-%{release}
Obsoletes:      python-xcb-proto-devel < %{version}-%{release}
Provides:       python-xcb-proto-devel = 7.6
Obsoletes:      python-xcb-proto-devel <= 7.6

%description -n python2-xcb-proto-devel
Language-independent Python libraries that used to parse an XML description
and create objects used by Python code generators in individual language
bindings.

%package -n python3-xcb-proto-devel
Summary:        Python libraries mandatory for XML-XCB Development
Group:          Development/Libraries/X11

%description -n python3-xcb-proto-devel
Language-independent Python libraries that used to parse an XML description
and create objects used by Python code generators in individual language
bindings.

%prep
%setup -q -n %{name}-%{dirsuffix}
%autopatch -p1

%build
autoreconf -fiv
%if %{with python2}
export PYTHON="python2"
%else
export PYTHON="python3"
%endif
%configure
make %{?_smp_mflags}

%install
%make_install
%fdupes %{buildroot}/%{_prefix}

%files devel
%dir %{_datadir}/xcb
%doc %{_datadir}/xcb/*
%{_datadir}/pkgconfig/*.pc

%if %{with python2}
%files -n python2-xcb-proto-devel
%doc COPYING
%{python_sitelib}/xcbgen/
%else

%files -n python3-xcb-proto-devel
%license COPYING
%{python3_sitelib}/xcbgen/
%endif

%changelog
* Sat Aug 26 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.16.0
  * gitlab CI: add a basic build test
  * Add documentation for DAMAGE extension
  * Remove "All rights reserved" from Oracle copyright notices
  * dpms: Add DPMSInfoNotify event (DPMS 1.2)
  * Document the MIT-SHM extension
  * Add documentation for XFixes v6
  * Document BIG-REQUESTS
  * Add documentation for Composite
  * autogen.sh: use quoted string variables
  * autogen: add default patch prefix
  * autogen.sh: use exec instead of waiting for configure to finish
  * xinput: qualify CW as from xproto
  * add PresentOptionAsyncMayTear
* Thu Feb  2 2023 Stefan Dirsch <sndirsch@suse.com>
- no longer let xcb-proto-devel provide/obsolete
  xorg-x11-proto-devel; this looks weird ...
* Mon Jun 20 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.15.2
  * dri3: Update dri3.xml to DRI3 1.3
  * Add DOUBLE-BUFFER extension specification.
  * Remove libdir from xcb-proto.pc
  * Install xcb-proto to $(datarootdir)
  * Call AC_OUTPUT without arguments
* Tue May  3 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.15
  * xproto.xml: Update doc text for GrabKey
  * Fix python version check from 65169c1af7893882c21d1e2a544903212b8d6fb0
  * Adjust to automake 1.16.4 changes
  * xfixes: Add ClientDisconnectMode
  * glx,xprint: place explicit padding between lists
  * Add element to specify expression that defines length of a struct
  * xinput: Add length specification for DeviceClass struct
  * xinput: Add XI v2.4
  * Add missing fields to errors
  * Use xml.etree.cElementTree where appropriate
* Fri Oct  9 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.14.1
  * This minor bug fix release provides compatibility with
    Python 3.9 by replacing usage of deprecated API's which
    were removed in Python 3.9.
* Mon Feb 24 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.14
  * Update README for gitlab migration
  * pkg-config: Add sysroot prefix
  * screensaver: Use CARD32 encoding for ScreenSaverSuspend 'suspend'
  * Removed unused member "fds"
  * Fix size computation of imported lists
  * Allow access to the original type in the XML
* Mon Mar  5 2018 sndirsch@suse.com
- Update to version 1.13
  * This release of xcb-proto brings support for buffer modifiers and
    multi-planar buffers through DRI3 v1.2 and Present v1.2, support for
    leasing KMS devices to clients via RandR 1.6, and also allows clients
    to send each other XInput2 events via support for the GenericEvent
    extension's SendExtension event.
- supersedes U_xinput-typedef-for-event_type_base.patch,
  U_add-support-for-eventstruct.patch,
  U_SendExtensionEvent-uses-eventstruct.patch,
  U_python-whitespace.patch,
  U_python3-compat.patch
* Wed Jan 17 2018 tchvatal@suse.com
- Tweak the python conditions to pick between py2 and py3 only
  do not bother with "both at once" scenario
- Apply patches to make sure we really work with python3:
  * U_python-whitespace.patch
  * U_python3-compat.patch
* Mon Jan  8 2018 msrb@suse.com
- Update xinput to the state when it was enabled by default
  upstream. (bnc#1074249)
  * U_SendExtensionEvent-uses-eventstruct.patch
  * U_add-support-for-eventstruct.patch
  * U_xinput-typedef-for-event_type_base.patch
* Tue Dec  5 2017 msrb@suse.com
- Python2 is gone since suse_version >= 1500.
* Thu Nov 16 2017 dimstar@opensuse.org
- Shrink dep-chain: we only need a python interpreter, not the
  entire devel suite. Replace python[23]-devel BuildRequires with
  python[23]-base.
* Wed Nov  1 2017 mpluskal@suse.com
- Build both python2 and python3 versions
- Run spec-cleaner
* Thu May 19 2016 sndirsch@suse.com
- Update to version 1.12
  * here is a new version of xcb-proto for you to enjoy. Highlights
    are lots of improvements especially to the xinput extension,
    support for RandR 1.5 and an automatic alignment checker.
* Wed Dec 16 2015 fcrozat@suse.com
- Add provides/obsoletes to python-xcb-proto-devel to ease upgrade.
* Thu Sep 18 2014 jengelh@inai.de
- Update description and other metadata
- Use full %%configure for build, and remove CFLAGS (nothing is
  compiled)
- Make file list more compact
* Tue Aug  5 2014 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.11 (7.6_1.11):
  Minor bug fixes and things that libxcb 1.11 will need.
* Tue Apr 29 2014 sndirsch@suse.com
- added COPYING to %%doc
* Tue Apr 29 2014 cfarrell@suse.com
- license update: X11
  See COPYING
* Sun Apr 27 2014 sndirsch@suse.com
- raise version number to 7.6_1.10 and provide/obsolete
  xorg-x11-proto-devel in the hope to fix build deps
* Wed Apr 23 2014 tobias.johannes.klausmann@mni.thm.de
- Created package xcb-proto with initial version 1.10
